:mod:`art.detection`
====================
.. automodule:: art.detection

Binary Input Detector
---------------------
.. autoclass:: BinaryInputDetector
   :members:

Binary Activation Detector
--------------------------
.. autoclass:: BinaryActivationDetector
   :members:
